.. PISCOLA documentation master file, created by
   sphinx-quickstart on Mon Jul  1 13:44:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HostPhot's documentation!
====================================

HostPhot is being actively developed in `a public repository on GitHub
<https://github.com/temuller/hostphot>`_ so if you have any trouble, `open an issue
<https://github.com/temuller/hostphot/issues>`_ there.

.. image:: https://img.shields.io/badge/GitHub-temuller%2Fpiscola-blue.svg?style=flat
    :target: https://github.com/temuller/hostphot
.. image:: https://readthedocs.org/projects/piscola/badge/?version=latest&style=flat
    :target: https://hostphot.readthedocs.io/en/latest/?badge=latest
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
    :target: https://github.com/temuller/hostphot/blob/master/LICENSE


.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   setup/installation.rst

.. toctree::
   :maxdepth: 1
   :caption: Examples

   examples/cutouts_example.rst
   examples/photometry_example.rst

.. toctree::
   :maxdepth: 2
   :caption: API User Guide

   user/cutouts.rst
   user/local_photometry.rst
   user/global_photometry.rst
   user/phot_utils.rst
   user/utils.rst

.. toctree::
   :maxdepth: 1
   :caption: About the Code

   about/details.rst


License & Attribution
---------------------

Copyright 2022 Tomás E. Müller Bravo.

PISCOLA is being developed by `Tomás E. Müller Bravo <https://temuller.github.io/>`_ in a
`public GitHub repository <https://github.com/hostphot/piscola>`_.
The source code is made available under the terms of the MIT license.
